diff --git a/modules/toolbar/toolbar.module b/modules/toolbar/toolbar.module
index 6d1b581..67b217d 100644
--- a/modules/toolbar/toolbar.module
+++ b/modules/toolbar/toolbar.module
@@ -70,7 +70,7 @@ function toolbar_menu() {
 function toolbar_toggle_page() {
   global $base_path;
   // Toggle the value in the cookie.
-  setcookie('Drupal.toolbar.collapsed', !_toolbar_is_collapsed(), NULL, $base_path);
+  setcookie('Drupal.toolbar.expanded', !_toolbar_is_expanded(), NULL, $base_path);
   // Redirect the user from where he used the toggle element.
   drupal_goto();
 }
@@ -103,12 +103,12 @@ function theme_toolbar_toggle($variables) {
  * Determines the current state of the toolbar drawer's visibility.
  *
  * @return
- *   TRUE when drawer is collapsed, FALSE when it is expanded.
+ *   TRUE when drawer is expanded, FALSE when it is collapsed.
  */
-function _toolbar_is_collapsed() {
+function _toolbar_is_expanded() {
   // PHP converts dots into underscores in cookie names to avoid problems with
   // its parser, so we use a converted cookie name.
-  return isset($_COOKIE['Drupal_toolbar_collapsed']) ? $_COOKIE['Drupal_toolbar_collapsed'] : 0;
+  return isset($_COOKIE['Drupal_toolbar_expanded']) ? $_COOKIE['Drupal_toolbar_expanded'] : 0;
 }
 
 /**
@@ -143,7 +143,7 @@ function toolbar_pre_render($toolbar) {
 function toolbar_preprocess_html(&$vars) {
   if (isset($vars['page']['page_top']['toolbar']) && user_access('access toolbar')) {
     $vars['classes_array'][] = 'toolbar';
-    if (!_toolbar_is_collapsed()) {
+    if (!_toolbar_is_expanded()) {
       $vars['classes_array'][] = 'toolbar-drawer';
     }
   }
@@ -258,7 +258,7 @@ function toolbar_view() {
   // Add an anchor to be able to toggle the visibility of the drawer.
   $build['toolbar_toggle'] = array(
     '#theme' => 'toolbar_toggle',
-    '#collapsed' => _toolbar_is_collapsed(),
+    '#collapsed' => !_toolbar_is_expanded(),
     '#attributes' => array('class' => array('toggle')),
   );
 
@@ -267,7 +267,7 @@ function toolbar_view() {
     'toolbar-drawer',
     'clearfix',
   );
-  if(_toolbar_is_collapsed()) {
+  if(!_toolbar_is_expanded()) {
     $toolbar_drawer_classes[] = 'collapsed';
   }
   $build['toolbar_drawer_classes'] = implode(' ', $toolbar_drawer_classes);

diff --git a/modules/toolbar/toolbar.js b/modules/toolbar/toolbar.js
index d50f205..6a35135 100644
--- a/modules/toolbar/toolbar.js
+++ b/modules/toolbar/toolbar.js
@@ -25,15 +25,15 @@ Drupal.behaviors.toolbar = {
  * Retrieve last saved cookie settings and set up the initial toolbar state.
  */
 Drupal.toolbar.init = function() {
-  // Retrieve the collapsed status from a stored cookie.
-  var collapsed = $.cookie('Drupal.toolbar.collapsed');
+  // Retrieve the expanded status from a stored cookie.
+  var expanded = $.cookie('Drupal.toolbar.expanded');
 
   // Expand or collapse the toolbar based on the cookie value.
-  if (collapsed == 1) {
-    Drupal.toolbar.collapse();
+  if (expanded == 1) {
+    Drupal.toolbar.expand();
   }
   else {
-    Drupal.toolbar.expand();
+    Drupal.toolbar.collapse();
   }
 };
 
@@ -42,15 +42,15 @@ Drupal.toolbar.init = function() {
  */
 Drupal.toolbar.collapse = function() {
   var toggle_text = Drupal.t('Show shortcuts');
-  $('#toolbar div.toolbar-drawer').addClass('collapsed');
+  $('#toolbar div.toolbar-drawer').addClass('expanded');
   $('#toolbar a.toggle')
     .removeClass('toggle-active')
     .attr('title',  toggle_text)
     .html(toggle_text);
   $('body').removeClass('toolbar-drawer').css('paddingTop', Drupal.toolbar.height());
   $.cookie(
-    'Drupal.toolbar.collapsed',
-    1,
+    'Drupal.toolbar.expanded',
+    0,
     {
       path: Drupal.settings.basePath,
       // The cookie should "never" expire.
@@ -64,15 +64,15 @@ Drupal.toolbar.collapse = function() {
  */
 Drupal.toolbar.expand = function() {
   var toggle_text = Drupal.t('Hide shortcuts');
-  $('#toolbar div.toolbar-drawer').removeClass('collapsed');
+  $('#toolbar div.toolbar-drawer').removeClass('expanded');
   $('#toolbar a.toggle')
     .addClass('toggle-active')
     .attr('title',  toggle_text)
     .html(toggle_text);
   $('body').addClass('toolbar-drawer').css('paddingTop', Drupal.toolbar.height());
   $.cookie(
-    'Drupal.toolbar.collapsed',
-    0,
+    'Drupal.toolbar.expanded',
+    1,
     {
       path: Drupal.settings.basePath,
       // The cookie should "never" expire.
@@ -85,11 +85,11 @@ Drupal.toolbar.expand = function() {
  * Toggle the toolbar.
  */
 Drupal.toolbar.toggle = function() {
-  if ($('#toolbar div.toolbar-drawer').hasClass('collapsed')) {
+  if ($('#toolbar div.toolbar-drawer').hasClass('expanded')) {
     Drupal.toolbar.expand();
   }
   else {
-    Drupal.toolbar.collapse();
+    Drupal.toolbar.expand();
   }
 };
 